==> easynetflutter-0.0.22.tar.gz: lib/easynet/util/EasyPlatfom.dart <==

import 'dart:io';

import 'package:easynetflutter/easynet/model/SystemConfig.dart';
import 'package:package_info/package_info.dart';

class EasyPlatfom{

  //static final bool isWindows = (_operatingSystem == "windows");
  static bool isWindows() {
    try {
      return Platform.isWindows;
    } catch (e){
      return false;
    }
  }

  static bool isMacOS() {
    try {
      return Platform.isMacOS;
    } catch (e){
      return false;
    }
  }

  static bool isAndroid() {
    try {
      return Platform.isAndroid;
    } catch (e){
      return false;
    }
  }
  static bool isIOS() {
    try {
      return Platform.isIOS;
    } catch (e){
      return false;
    }
  }
  static bool isLinux() {
    try {
      return Platform.isMacOS;
    } catch (e){
      return false;
    }
  }
  static bool isFuchsia() {
    try {
      return Platform.isMacOS;
    } catch (e){
      return false;
    }
  }

  static bool isWeb() {
    try {
      return Platform.isMacOS;
    } catch (e){
      return true;
    }
  }

  static Future<SystemConfig> loadPackageInfo() async {
    if (isWeb()) {
      return null;
    } else {
      PackageInfo packageInfo = await PackageInfo.fromPlatform();

      String appName = packageInfo.appName;
      String packageName = packageInfo.packageName;
      String version = packageInfo.version;
      String buildNumber = packageInfo.buildNumber;
      return SystemConfig(appName: appName,
          packageName: packageName,
          version: version,
          buildNumber: buildNumber);
    }
  }
}

==> easynetflutter-0.0.38.tar.gz: lib/easynet/util/EasyPlatfom.dart <==

import 'dart:io';

import 'package:easynetflutter/easynet/model/SystemConfig.dart';
import 'package:package_info/package_info.dart';

class EasyPlatfom{

  //static final bool isWindows = (_operatingSystem == "windows");
  static bool isWindows() {
    try {
      return Platform.isWindows;
    } catch (e){
      return false;
    }
  }

  static bool isMacOS() {
    try {
      return Platform.isMacOS;
    } catch (e){
      return false;
    }
  }

  static bool isAndroid() {
    try {
      return Platform.isAndroid;
    } catch (e){
      return false;
    }
  }
  static bool isIOS() {
    try {
      return Platform.isIOS;
    } catch (e){
      return false;
    }
  }
  static bool isLinux() {
    try {
      return Platform.isMacOS;
    } catch (e){
      return false;
    }
  }
  static bool isFuchsia() {
    try {
      return Platform.isMacOS;
    } catch (e){
      return false;
    }
  }

  static bool isWeb() {
    try {
      return Platform.isMacOS;
    } catch (e){
      return true;
    }
  }

  static SystemConfig loadPackageInfo()  {
    if (isWeb()) {
      return SystemConfig(appName: "",
          packageName: "",
          version: "",
          buildNumber: "");
    } else {
      PackageInfo packageInfo;
      PackageInfo.fromPlatform().then((value) => packageInfo = value).
      whenComplete(() {
        String appName = packageInfo.appName;
        String packageName = packageInfo.packageName;
        String version = packageInfo.version;
        String buildNumber = packageInfo.buildNumber;
        return SystemConfig(appName: appName,
            packageName: packageName,
            version: version,
            buildNumber: buildNumber);
      });
    }
  }
}
